==> tomcat7_7.0.21.orig.tar.gz: tomcat7-7.0.21/modules/jdbc-pool/src/test/java/org/apache/tomcat/jdbc/test/Async0IdleTestBug50477.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.jdbc.test;

import java.sql.Connection;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

import org.apache.tomcat.jdbc.pool.DataSourceProxy;

/**
 * @author Filip Hanik
 * @version 1.0
 */
public class Async0IdleTestBug50477 extends DefaultTestCase {
    public Async0IdleTestBug50477(String name) {
        super(name);
    }
    
 
    public void testAsync0Idle0Size() throws Exception {
        System.out.println("[testPoolThreads20Connections10FairAsync] Starting fairness - Tomcat JDBC - Fair - Async");
        init();
        this.datasource.getPoolProperties().setMaxActive(10);
        this.datasource.getPoolProperties().setFairQueue(true);
        this.datasource.getPoolProperties().setInitialSize(0);
        try {
            Future<Connection> cf = ((DataSourceProxy)datasource).getConnectionAsync();
            Connection con  = cf.get(5, TimeUnit.SECONDS);
        }finally {
            tearDown();
        }
    }
}

==> tomcat7_7.0.22.orig.tar.gz: tomcat7-7.0.22/modules/jdbc-pool/src/test/java/org/apache/tomcat/jdbc/test/Async0IdleTestBug50477.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.jdbc.test;

import java.sql.Connection;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

import org.apache.tomcat.jdbc.pool.DataSourceProxy;

/**
 * @author Filip Hanik
 * @version 1.0
 */
public class Async0IdleTestBug50477 extends DefaultTestCase {
    public Async0IdleTestBug50477(String name) {
        super(name);
    }
    
 
    public void testAsync0Idle0Size() throws Exception {
        System.out.println("[testPoolThreads20Connections10FairAsync] Starting fairness - Tomcat JDBC - Fair - Async");
        init();
        this.datasource.getPoolProperties().setMaxActive(10);
        this.datasource.getPoolProperties().setFairQueue(true);
        this.datasource.getPoolProperties().setInitialSize(0);
        try {
            Future<Connection> cf = ((DataSourceProxy)datasource).getConnectionAsync();
            cf.get(5, TimeUnit.SECONDS);
        }finally {
            tearDown();
        }
    }
}
